@@ -39,7 +39,6 @@ apt-get install -y --no-install-recommends \
     aptitude \
     ca-certificates \
     cgroupfs-mount \
-    docker-compose \
     containerd.io \
     docker-ce="5:19.03.14~3-0~ubuntu-bionic" \
     docker-ce-cli="5:19.03.14~3-0~ubuntu-bionic" \
@@ -59,11 +58,17 @@ apt-get install -y --no-install-recommends \
 
 cp -R /etc/alternatives /etc/keep-alternatives
 apt-get install -y --no-install-recommends \
+    openjdk-8-jdk \
+    openjdk-11-jdk \
     bellsoft-java11 \
     bellsoft-java8
 rm -rf /etc/alternatives
 mv /etc/keep-alternatives /etc/alternatives
 
+pip3 install --upgrade pip
+pip3 install setuptools
+pip3 install docker-compose
+
 pushd /tmp
   curl -O https://dl.google.com/dl/cloudsdk/channels/rapid/downloads/google-cloud-sdk-${CLOUD_SDK_VERSION}-linux-x86_64.tar.gz
   tar xzf google-cloud-sdk-${CLOUD_SDK_VERSION}-linux-x86_64.tar.gz -C /
