@@ -70,8 +70,10 @@ fi
 set -e
 set -x
 
-CONCOURSE_SCHEME=https
-CONCOURSE_URL=${CONCOURSE_SCHEME}://${CONCOURSE_HOST}
+if [[ "${CONCOURSE_HOST}" == "concourse.apachegeode-ci.info" ]]; then
+  CONCOURSE_SCHEME=https
+fi
+CONCOURSE_URL=${CONCOURSE_SCHEME:-"http"}://${CONCOURSE_HOST}
 FLY_TARGET=${CONCOURSE_HOST}-${CONCOURSE_TEAM}
 
 . ${SCRIPTDIR}/../shared/utilities.sh
@@ -130,15 +132,15 @@ YML
 
 
   set -e
-  if [[ "${UPSTREAM_FORK}" != "apache" ]]; then
-    ${FLY} -t ${FLY_TARGET} status || \
-    ${FLY} -t ${FLY_TARGET} login \
+  if [[ ${UPSTREAM_FORK} != "apache" ]]; then
+    fly -t ${FLY_TARGET} status || \
+    fly -t ${FLY_TARGET} login \
            --team-name ${CONCOURSE_TEAM} \
            --concourse-url=${CONCOURSE_URL}
   fi
 
-  ${FLY} -t ${FLY_TARGET} sync
-  ${FLY} -t ${FLY_TARGET} set-pipeline \
+  fly -t ${FLY_TARGET} sync
+  fly -t ${FLY_TARGET} set-pipeline \
     -p ${META_PIPELINE} \
     --config ${SCRIPTDIR}/generated-pipeline.yml \
     --var artifact-bucket=${ARTIFACT_BUCKET} \
@@ -166,19 +168,19 @@ popd 2>&1 > /dev/null
 function jobStatus {
   PIPELINE=$1
   JOB=$2
-  ${FLY} jobs -t ${FLY_TARGET} -p ${PIPELINE}|awk "/${JOB}/"'{if($2=="yes")print "paused";else if($4!="n/a")print $4; else print $3}'
+  fly jobs -t ${FLY_TARGET} -p ${PIPELINE}|awk "/${JOB}/"'{if($2=="yes")print "paused";else if($4!="n/a")print $4; else print $3}'
 }
 
 function triggerJob {
   PIPELINE=$1
   JOB=$2
-  (set -x ; ${FLY} trigger-job -t ${FLY_TARGET} -j ${PIPELINE}/${JOB})
+  (set -x ; fly trigger-job -t ${FLY_TARGET} -j ${PIPELINE}/${JOB})
 }
 
 function pauseJob {
   PIPELINE=$1
   JOB=$2
-  (set -x ; ${FLY} pause-job -t ${FLY_TARGET} -j ${PIPELINE}/${JOB})
+  (set -x ; fly pause-job -t ${FLY_TARGET} -j ${PIPELINE}/${JOB})
 }
 
 function pauseJobs {
@@ -201,7 +203,7 @@ function pauseNewJobs {
 function unpauseJob {
   PIPELINE=$1
   JOB=$2
-  (set -x ; ${FLY} unpause-job -t ${FLY_TARGET} -j ${PIPELINE}/${JOB})
+  (set -x ; fly unpause-job -t ${FLY_TARGET} -j ${PIPELINE}/${JOB})
 }
 
 function unpauseJobs {
@@ -214,12 +216,12 @@ function unpauseJobs {
 
 function unpausePipeline {
   PIPELINE=$1
-  (set -x ; ${FLY} -t ${FLY_TARGET} unpause-pipeline -p ${PIPELINE})
+  (set -x ; fly -t ${FLY_TARGET} unpause-pipeline -p ${PIPELINE})
 }
 
 function exposePipeline {
   PIPELINE=$1
-  (set -x ; ${FLY} -t ${FLY_TARGET} expose-pipeline -p ${PIPELINE})
+  (set -x ; fly -t ${FLY_TARGET} expose-pipeline -p ${PIPELINE})
 }
 
 function exposePipelines {
@@ -281,7 +283,7 @@ elif [[ "$GEODE_FORK" == "${UPSTREAM_FORK}" ]] && [[ "$GEODE_BRANCH" == "develop
   echo "Disabling optional jobs for develop"
   pauseNewJobs ${META_PIPELINE} set-pr-pipeline set-examples-pipeline
 else
-  echo "Disabling unnecessary jobs for release branches."
+  echo "Disabling unnecessary jobs for support branches."
   echo "*** DO NOT RE-ENABLE THESE META-JOBS ***"
   pauseJobs ${META_PIPELINE} set-images-pipeline set-reaper-pipeline
   pauseNewJobs ${META_PIPELINE} set-pr-pipeline set-examples-pipeline
@@ -297,8 +299,8 @@ driveToGreen $META_PIPELINE set-pipeline
 unpausePipeline ${PIPELINE_PREFIX}main
 
 if [[ "$GEODE_FORK" == "${UPSTREAM_FORK}" ]]; then
-  exposePipelines ${PIPELINE_PREFIX}main ${PIPELINE_PREFIX}images
   if [[ "${PUBLIC}" == "true" ]]; then
+    exposePipelines ${PIPELINE_PREFIX}main ${PIPELINE_PREFIX}images
     enableFeature examples
   fi
   if [[ "$GEODE_BRANCH" == "develop" ]]; then
