@@ -48,24 +48,6 @@ if [[ -z "${IMAGE_FAMILY_NAME}" ]]; then
   exit 1
 fi
 
-if [[ -z "${GCP_NETWORK}" ]]; then
-  echo "GCP_NETWORK environment variable must be set for this script to work."
-  exit 1
-fi
-
-if [[ -z "${GCP_SUBNETWORK}" ]]; then
-  echo "GCP_SUBNETWORK environment variable must be set for this script to work."
-  exit 1
-fi
-
-if [[ -z "${GCP_ZONE}" ]]; then
-  echo "GCP_ZONE environment variable must be set for this script to work."
-  exit 1
-fi
-
-. ${SCRIPTDIR}/shared_utilities.sh
-is_source_from_pr_testable "geode" "$(get_geode_pr_exclusion_dirs)" || exit 0
-
 if [[ -d geode ]]; then
   pushd geode
   GEODE_SHA=$(git rev-parse --verify HEAD)
@@ -101,8 +83,14 @@ if [[ -z "${IMAGE_NAME}" ]]; then
   exit 1
 fi
 
-MY_ZONE=${GCP_ZONE}
+MY_NAME=$(curl -s "http://metadata.google.internal/computeMetadata/v1/instance/name" -H "Metadata-Flavor: Google")
+MY_ZONE=$(curl -s "http://metadata.google.internal/computeMetadata/v1/instance/zone" -H "Metadata-Flavor: Google")
 MY_ZONE=${MY_ZONE##*/}
+NETWORK_INTERFACE_INFO="$(gcloud compute instances describe ${MY_NAME} --zone ${MY_ZONE} --format="json(networkInterfaces)")"
+GCP_NETWORK=$(echo ${NETWORK_INTERFACE_INFO} | jq -r '.networkInterfaces[0].network')
+GCP_NETWORK=${GCP_NETWORK##*/}
+GCP_SUBNETWORK=$(echo ${NETWORK_INTERFACE_INFO} | jq -r '.networkInterfaces[0].subnetwork')
+GCP_SUBNETWORK=${GCP_SUBNETWORK##*/}
 
 # Determine and store our attempt number
 cp old/attempts new/
@@ -146,6 +134,7 @@ INSTANCE_INFORMATION=$(gcloud compute --project=${GCP_PROJECT} instances create
   --labels="${LABELS}" \
   --tags="heavy-lifter" \
   --scopes="default,storage-rw" \
+ `[[ ${USE_SCRATCH_SSD} == "true" ]] && echo "--local-ssd interface=scsi"` \
   --format=json)
 
 CREATE_RC=$?
@@ -164,6 +153,7 @@ INSTANCE_ID=$(echo ${INSTANCE_INFORMATION} | jq -r '.[].id')
 echo "Heavy lifter's Instance ID is: ${INSTANCE_ID}"
 
 echo "${INSTANCE_IP_ADDRESS}" > "instance-data/instance-ip-address"
+echo "${INSTANCE_ID}" > "instance-data/instance-id"
 
 if [[ -z "${WINDOWS_PREFIX}" ]]; then
   SSH_TIME=$(($(date +%s) + 60))
@@ -205,4 +195,21 @@ else
   winrm -hostname ${INSTANCE_IP_ADDRESS} -username geode -password "${PASSWORD}" \
     -https -insecure -port 5986 \
     "powershell -command \"&{ mkdir c:\users\geode\.ssh -force; set-content -path c:\users\geode\.ssh\authorized_keys -encoding utf8 -value '${KEY}' }\""
+
+  if [[ ${USE_SCRATCH_SSD} == "true" ]]; then
+    set +e
+    echo "Setting up local scratch SSD on drive Z"
+    winrm -hostname ${INSTANCE_IP_ADDRESS} -username geode -password "${PASSWORD}" \
+      -https -insecure -port 5986 \
+      "powershell -command \"Get-Disk\""
+
+    winrm -hostname ${INSTANCE_IP_ADDRESS} -username geode -password "${PASSWORD}" \
+      -https -insecure -port 5986 \
+      "powershell -command \"Get-Disk | Where partitionstyle -eq 'raw' | Initialize-Disk -PartitionStyle MBR -PassThru | New-Partition -DriveLetter Z -UseMaximumSize | Format-Volume -FileSystem NTFS -NewFileSystemLabel \“disk2\” -Confirm:\$false\""
+
+    winrm -hostname ${INSTANCE_IP_ADDRESS} -username geode -password "${PASSWORD}" \
+      -https -insecure -port 5986 \
+      "powershell -command \"Get-PSDrive\""
+    set -e
+  fi
 fi
