@@ -113,7 +113,7 @@ import org.apache.geode.test.junit.rules.serializable.SerializableTemporaryFolde
 @SuppressWarnings("serial")
 public class PersistentRecoveryOrderDUnitTest extends CacheTestCase {
 
-  private static final long TIMEOUT_MILLIS = getTimeout().getValueInMS();
+  private static final long TIMEOUT_MILLIS = getTimeout().toMillis();
   private static final AtomicBoolean SAW_REQUEST_IMAGE_MESSAGE = new AtomicBoolean();
   private static final AtomicReference<CountDownLatch> LATCH = new AtomicReference<>();
   private static final AtomicReference<CountDownLatch> SLEEP = new AtomicReference<>();
@@ -877,43 +877,11 @@ public class PersistentRecoveryOrderDUnitTest extends CacheTestCase {
         Throwable thrown = catchThrowable(() -> {
           createReplicateRegion(regionName, getDiskDirs(getVMId()));
         });
-        assertThat(thrown)
-            .isInstanceOf(ConflictingPersistentDataException.class)
-            .hasMessageContaining("was not part of the same distributed system as the local data");
+        assertThat(thrown).isInstanceOf(ConflictingPersistentDataException.class);
       }
     });
   }
 
-  @Test
-  public void testRecoverableSplitBrain() {
-    vm2.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-    });
-    vm0.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-      putEntry("A", "B");
-      getCache().getRegion(regionName).close();
-    });
-
-    vm1.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-      validateEntry("A", "B");
-      updateEntry("A", "C");
-      getCache().getRegion(regionName).close();
-    });
-
-    // VM0 doesn't know that VM1 ever existed so it will start up.
-    vm0.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-      validateEntry("A", "C");
-    });
-
-    vm1.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-      validateEntry("A", "C");
-    });
-  }
-
   /**
    * Test to make sure that if if a member crashes while a GII is in progress, we wait for the
    * member to come back for starting.
