@@ -53,7 +53,7 @@ import org.apache.geode.logging.internal.log4j.api.LogService;
  * are assumed to be colocated, and the model adds together the load from each of the individual
  * regions to balance all of the regions together.
  *
- * Rebalancing operations are performed by repeatedly calling model.nextStep until it returns false.
+ * Reblancing operations are performed by repeatedly calling model.nextStep until it returns false.
  * Each call to nextStep should perform another operation. The model will make callbacks to the
  * BucketOperator you provide to the contructor perform the actual create or move.
  *
@@ -125,13 +125,9 @@ public class PartitionedRegionLoadModel {
   private final BucketOperator operator;
   private final int requiredRedundancy;
 
-  /**
-   * The average primary load on a member
-   */
+  /** The average primary load on a member */
   private float primaryAverage = -1;
-  /**
-   * The average bucket load on a member
-   */
+  /** The average bucket load on a member */
   private float averageLoad = -1;
   /**
    * The minimum improvement in variance that we'll consider worth moving a primary
@@ -155,8 +151,7 @@ public class PartitionedRegionLoadModel {
    * @param redundancyLevel The expected redundancy level for the region
    */
   public PartitionedRegionLoadModel(BucketOperator operator, int redundancyLevel, int numBuckets,
-      AddressComparor addressComparor,
-      Set<InternalDistributedMember> criticalMembers,
+      AddressComparor addressComparor, Set<InternalDistributedMember> criticalMembers,
       PartitionedRegion region) {
     this.operator = operator;
     this.requiredRedundancy = redundancyLevel;
@@ -297,7 +292,7 @@ public class PartitionedRegionLoadModel {
               new Object[] {memberRollup, this.allColocatedRegions,
                   memberRollup.getColocatedMembers().keySet(), memberRollup.getBuckets()});
         }
-        for (Bucket bucket : new HashSet<>(memberRollup.getBuckets())) {
+        for (Bucket bucket : new HashSet<Bucket>(memberRollup.getBuckets())) {
           bucket.removeMember(memberRollup);
         }
       }
@@ -367,6 +362,9 @@ public class PartitionedRegionLoadModel {
    * to create a bucket on that node. Because the bucket operator is asynchronous, the bucket may
    * not be created immediately, but the model will be updated regardless. Invoke
    * {@link #waitForOperations()} to wait for those operations to actually complete
+   *
+   * @param bucket the bucket for which a redundant copy should be made
+   * @param targetMember the member on which a redundant copy of a bucket should be made
    */
   public void createRedundantBucket(final BucketRollup bucket, final Member targetMember) {
     Map<String, Long> colocatedRegionSizes = getColocatedRegionSizes(bucket);
@@ -475,36 +473,21 @@ public class PartitionedRegionLoadModel {
     Move bestMove = null;
 
     for (Member member : bucket.getMembersHosting()) {
-
-      // If we can't delete it continue (last member of zone)
-      if (!member.canDelete(bucket, partitionedRegion.getDistributionManager()).willAccept()) {
-        continue;
-      }
-
-      // if this load is lower than then highest load, we prefer the deleting from high
-      // load servers so move on. If this member is the bucket primary, we prefer not to move
-      // primaries, so move on.
       float newLoad = (member.getTotalLoad() - bucket.getLoad()) / member.getWeight();
-      if (newLoad <= mostLoaded || member.equals(bucket.getPrimary())) {
-        continue;
+      if (newLoad > mostLoaded && !member.equals(bucket.getPrimary())) {
+        Move move = new Move(null, member, bucket);
+        if (!this.attemptedBucketRemoves.contains(move)) {
+          mostLoaded = newLoad;
+          bestMove = move;
+        }
       }
-
-      // if the attemptedBucketRemovesList contains this move, then we don't need to add it
-      // again.
-      Move move = new Move(null, member, bucket);
-      if (this.attemptedBucketRemoves.contains(move)) {
-        continue;
-      }
-
-      mostLoaded = newLoad;
-      bestMove = move;
     }
     return bestMove;
   }
 
   public Move findBestTargetForFPR(Bucket bucket, boolean checkIPAddress) {
-    InternalDistributedMember targetMemberID;
-    Member targetMember;
+    InternalDistributedMember targetMemberID = null;
+    Member targetMember = null;
     List<FixedPartitionAttributesImpl> fpas =
         this.partitionedRegion.getFixedPartitionAttributesImpl();
 
@@ -773,8 +756,8 @@ public class PartitionedRegionLoadModel {
   /**
    * For testing only, calculate the total variance of the members
    */
-  public float getVarianceForTest() {
-    float variance = 0;
+  public double getVarianceForTest() {
+    double variance = 0;
 
     for (Member member : this.members.values()) {
       variance += variance(member.getTotalLoad(), member.getWeight(), getAverageLoad());
@@ -786,8 +769,8 @@ public class PartitionedRegionLoadModel {
   /**
    * For testing only, calculate the total variance of the members
    */
-  public float getPrimaryVarianceForTest() {
-    float variance = 0;
+  public double getPrimaryVarianceForTest() {
+    double variance = 0;
 
     for (Member member : this.members.values()) {
       variance += variance(member.getPrimaryLoad(), member.getWeight(), getPrimaryAverage());
