@@ -35,6 +35,7 @@ import org.apache.logging.log4j.Logger;
 
 import org.apache.geode.SystemFailure;
 import org.apache.geode.alerting.internal.spi.AlertingAction;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.annotations.internal.MakeNotStatic;
 import org.apache.geode.distributed.DistributedMember;
 import org.apache.geode.distributed.DistributedSystemDisconnectedException;
@@ -161,14 +162,6 @@ public class ConnectionTable {
     threadWantsOwnResources.set(Boolean.TRUE);
   }
 
-  public static int getNumSenderSharedConnections() {
-    ConnectionTable ct = (ConnectionTable) lastInstance.get();
-    if (ct == null) {
-      return 0;
-    }
-    return (ct.getConduit().getStats().getSendersSU());
-  }
-
   /**
    * Returns true if calling thread owns its own communication resources.
    */
@@ -282,10 +275,9 @@ public class ConnectionTable {
     // handle new pending connection
     Connection con = null;
     try {
-      long senderCreateStartTime = owner.getStats().startSenderCreate();
       con = Connection.createSender(owner.getMembership(), this, preserveOrder, id,
           sharedResource, startTime, ackThreshold, ackSAThreshold);
-      owner.getStats().incSenders(sharedResource, preserveOrder, senderCreateStartTime);
+      owner.getStats().incSenders(sharedResource, preserveOrder);
     } finally {
       // our connection failed to notify anyone waiting for our pending con
       if (con == null) {
@@ -448,13 +440,12 @@ public class ConnectionTable {
     }
 
     // OK, we have to create a new connection.
-    long senderCreateStartTime = owner.getStats().startSenderCreate();
     result = Connection.createSender(owner.getMembership(), this, true, id, false, startTime,
         ackTimeout, ackSATimeout);
-    owner.getStats().incSenders(false, true, senderCreateStartTime);
     if (logger.isDebugEnabled()) {
       logger.debug("ConnectionTable: created an ordered connection: {}", result);
     }
+    owner.getStats().incSenders(false, true);
 
     // Update the list of connections owned by this thread....
 
@@ -885,6 +876,17 @@ public class ConnectionTable {
     }
   }
 
+  @VisibleForTesting
+  public static int getNumSenderSharedConnections() {
+    ConnectionTable ct = (ConnectionTable) lastInstance.get();
+    if (ct == null) {
+      return 0;
+    }
+    return (ct.getConduit().getStats().getSendersSU());
+  }
+
+
+
   /**
    * Clears lastInstance. Does not yet close underlying sockets, but probably not strictly
    * necessary.
