@@ -14,8 +14,8 @@
  */
 package org.apache.geode.cache.query.cq.dunit;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.LOG_LEVEL;
-import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.apache.geode.test.dunit.Assert.assertEquals;
 import static org.apache.geode.test.dunit.Assert.assertFalse;
 import static org.apache.geode.test.dunit.Assert.assertNotNull;
@@ -137,7 +137,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
 
     server1.invoke(() -> {
       Region<String, Object> region =
-          getCache().getRegion("/root/" + regions[0]);
+          getCache().getRegion(SEPARATOR + "root" + SEPARATOR + regions[0]);
       Map<String, Object> buffer = new HashMap();
       for (int i = 1; i < numObjects; i++) {
         Portfolio p = new Portfolio(i);
@@ -158,7 +158,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
 
     server1.invoke(() -> {
       Region<String, Object> region =
-          getCache().getRegion("/root/" + regions[0]);
+          getCache().getRegion(SEPARATOR + "root" + SEPARATOR + regions[0]);
       // PutAll with entries that do not satisfy CQ. This is to generate LOCAL_DESTROY CQ event
       Map<String, Object> buffer = new HashMap();
       for (int i = 1; i < numObjects; i++) {
@@ -177,8 +177,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
           .isNotNull();
       CqQueryTestListener cqListener =
           (CqQueryTestListener) cqQuery.getCqAttributes().getCqListener();
-      await().untilAsserted(
-          () -> assertThat(cqListener.getTotalEventCount()).isEqualTo(numObjects - 1));
+      assertThat(cqListener.getTotalEventCount()).isEqualTo(numObjects - 1);
     });
 
     cqHelper.closeClient(client);
@@ -204,7 +203,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
 
     server1.invoke(() -> {
       Region<String, Object> region =
-          getCache().getRegion("/root/" + regions[0]);
+          getCache().getRegion(SEPARATOR + "root" + SEPARATOR + regions[0]);
       Map<String, Object> buffer = new HashMap();
       for (int i = 1; i < numObjects; i++) {
         Portfolio p = new Portfolio(i);
@@ -225,7 +224,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
 
     server1.invoke(() -> {
       Region<String, Object> region =
-          getCache().getRegion("/root/" + regions[0]);
+          getCache().getRegion(SEPARATOR + "root" + SEPARATOR + regions[0]);
       Set<String> keys = new HashSet<>();
       for (int i = 1; i < numObjects; i++) {
         keys.add("" + i);
@@ -243,8 +242,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
           .isNotNull();
       CqQueryTestListener cqListener =
           (CqQueryTestListener) cqQuery.getCqAttributes().getCqListener();
-      await().untilAsserted(
-          () -> assertThat(cqListener.getTotalEventCount()).isEqualTo(numObjects - 1));
+      assertThat(cqListener.getTotalEventCount()).isEqualTo(numObjects - 1);
     });
 
     cqHelper.closeClient(client);
