@@ -82,6 +82,7 @@ import org.apache.geode.distributed.internal.membership.gms.GMSMembershipView;
 import org.apache.geode.distributed.internal.membership.gms.GMSUtil;
 import org.apache.geode.distributed.internal.membership.gms.Services;
 import org.apache.geode.distributed.internal.membership.gms.interfaces.HealthMonitor;
+import org.apache.geode.distributed.internal.membership.gms.interfaces.Manager;
 import org.apache.geode.distributed.internal.membership.gms.interfaces.MessageHandler;
 import org.apache.geode.distributed.internal.membership.gms.interfaces.Messenger;
 import org.apache.geode.distributed.internal.membership.gms.locator.FindCoordinatorRequest;
@@ -178,7 +179,7 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
    * The JGroupsReceiver is handed messages by the JGroups Channel. It is responsible
    * for deserializating and dispatching those messages to the appropriate handler
    */
-  private JGroupsReceiver jgroupsReceiver;
+  protected JGroupsReceiver jgroupsReceiver;
 
   public static void setChannelReceiver(JChannel channel, Receiver r) {
     try {
@@ -330,12 +331,15 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
     // start the jgroups channel and establish the membership ID
     boolean reconnecting = false;
     try {
-      Object oldDSMembershipInfo = services.getConfig().getOldDSMembershipInfo();
+      Object oldDSMembershipInfo = services.getConfig().getOldMembershipInfo();
       if (oldDSMembershipInfo != null) {
-        logger.debug("Reusing JGroups channel from previous system", properties);
+        if (logger.isDebugEnabled()) {
+          logger.debug("Reusing JGroups channel from previous system", properties);
+        }
         MembershipInformationImpl oldInfo = (MembershipInformationImpl) oldDSMembershipInfo;
         myChannel = oldInfo.getChannel();
         queuedMessagesFromReconnect = oldInfo.getQueuedMessages();
+        encrypt = oldInfo.getEncrypt();
 
         // scrub the old channel
         ViewId vid = new ViewId(new JGAddress(), 0);
@@ -356,7 +360,9 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
         }
         reconnecting = true;
       } else {
-        logger.debug("JGroups configuration: {}", properties);
+        if (logger.isDebugEnabled()) {
+          logger.debug("JGroups configuration: {}", properties);
+        }
 
         checkForIPv6();
         InputStream is = new ByteArrayInputStream(properties.getBytes("UTF-8"));
@@ -408,7 +414,10 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
   private void checkForIPv6() throws Exception {
     boolean preferIpV6Addr = Boolean.getBoolean("java.net.preferIPv6Addresses");
     if (!preferIpV6Addr) {
-      logger.debug("forcing JGroups to think IPv4 is being used so it will choose an IPv4 address");
+      if (logger.isDebugEnabled()) {
+        logger
+            .debug("forcing JGroups to think IPv4 is being used so it will choose an IPv4 address");
+      }
       Field m = org.jgroups.util.Util.class.getDeclaredField("ip_stack_type");
       m.setAccessible(true);
       m.set(null, org.jgroups.util.StackType.IPv4);
@@ -417,7 +426,7 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
 
   @Override
   public void started() throws MemberStartupException {
-    if (queuedMessagesFromReconnect != null && !services.getConfig().isUDPSecurityEnabled()) {
+    if (queuedMessagesFromReconnect != null) {
       logger.info("Delivering {} messages queued by quorum checker",
           queuedMessagesFromReconnect.size());
       for (org.jgroups.Message message : queuedMessagesFromReconnect) {
@@ -457,7 +466,9 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
     List<JGAddress> mbrs = v.getMembers().stream().map(JGAddress::new).collect(Collectors.toList());
     ViewId vid = new ViewId(new JGAddress(v.getCoordinator()), v.getViewId());
     View jgv = new View(vid, new ArrayList<>(mbrs));
-    logger.trace("installing view into JGroups stack: {}", jgv);
+    if (logger.isTraceEnabled()) {
+      logger.trace("installing view into JGroups stack: {}", jgv);
+    }
     this.myChannel.down(new Event(Event.VIEW_CHANGE, jgv));
 
     addressesWithIoExceptionsProcessed.clear();
@@ -696,7 +707,9 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
 
     if (logger.isDebugEnabled() && reliably) {
       String recips = useMcast ? "multicast" : destinations.toString();
-      logger.debug("sending via JGroups: [{}] recipients: {}", msg, recips);
+      if (logger.isDebugEnabled()) {
+        logger.debug("sending via JGroups: [{}] recipients: {}", msg, recips);
+      }
     }
 
     JGAddress local = this.jgAddress;
@@ -721,10 +734,14 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
           jmsg.setFlag(org.jgroups.Message.Flag.NO_RELIABILITY);
         }
         theStats.incSentBytes(jmsg.getLength());
-        logger.trace("Sending JGroups message: {}", jmsg);
+        if (logger.isTraceEnabled()) {
+          logger.trace("Sending JGroups message: {}", jmsg);
+        }
         myChannel.send(jmsg);
       } catch (Exception e) {
-        logger.debug("caught unexpected exception", e);
+        if (logger.isDebugEnabled()) {
+          logger.debug("caught unexpected exception", e);
+        }
         Throwable cause = e.getCause();
         if (cause instanceof MemberDisconnectedException) {
           problem = (Exception) cause;
@@ -811,7 +828,9 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
           }
           tmp.setDest(to);
           tmp.setSrc(this.jgAddress);
-          logger.trace("Unicasting to {}", to);
+          if (logger.isTraceEnabled()) {
+            logger.trace("Unicasting to {}", to);
+          }
           myChannel.send(tmp);
         } catch (Exception e) {
           problem = e;
@@ -848,7 +867,9 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
     if (newView != null && newView != oldView) {
       for (ID d : destinations) {
         if (!newView.contains(d)) {
-          logger.debug("messenger: member has left the view: {}  view is now {}", d, newView);
+          if (logger.isDebugEnabled()) {
+            logger.debug("messenger: member has left the view: {}  view is now {}", d, newView);
+          }
           failedRecipients.add(d);
         }
       }
@@ -1012,7 +1033,9 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
     if (messageLength == 0) {
       // jgroups messages with no payload are used for protocol interchange, such
       // as STABLE_GOSSIP
-      logger.trace("message length is zero - ignoring");
+      if (logger.isTraceEnabled()) {
+        logger.trace("message length is zero - ignoring");
+      }
       return null;
     }
 
@@ -1195,7 +1218,9 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
           try {
             Digest digest = new Digest();
             digest.readFrom(dis);
-            logger.trace("installing JGroups message digest {} from {}", digest, m);
+            if (logger.isTraceEnabled()) {
+              logger.trace("installing JGroups message digest {} from {}", digest, m);
+            }
             this.myChannel.getProtocolStack().getTopProtocol()
                 .down(new Event(Event.MERGE_DIGEST, digest));
             jrsp.setMessengerData(null);
@@ -1248,7 +1273,8 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
       }
     }
     GMSQuorumChecker<ID> qc =
-        new GMSQuorumChecker<>(view, services.getConfig().getLossThreshold(), this.myChannel);
+        new GMSQuorumChecker<>(view, services.getConfig().getLossThreshold(), this.myChannel,
+            encrypt);
     qc.initialize();
     return qc;
   }
@@ -1264,7 +1290,7 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
       receive(jgmsg, false);
     }
 
-    private void receive(org.jgroups.Message jgmsg, boolean fromQuorumChecker) {
+    protected void receive(org.jgroups.Message jgmsg, boolean fromQuorumChecker) {
       long startTime = services.getStatistics().startUDPDispatchRequest();
       try {
         if (services.getManager().shutdownInProgress()) {
@@ -1318,9 +1344,12 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
           }
           filterIncomingMessage(msg);
           MessageHandler<Message<ID>> handler = getMessageHandler(msg);
-          if (fromQuorumChecker && handler instanceof HealthMonitor) {
+          if (fromQuorumChecker
+              && (handler instanceof HealthMonitor || handler instanceof Manager)) {
             // ignore suspect / heartbeat messages that happened during
-            // auto-reconnect because they very likely have old member IDs in them
+            // auto-reconnect because they very likely have old member IDs in them.
+            // Also ignore non-membership messages because we weren't a member when we received
+            // them.
           } else {
             handler.processMessage(msg);
           }
@@ -1393,7 +1422,9 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
   @Override
   public void setPublicKey(byte[] publickey, ID mbr) {
     if (encrypt != null) {
-      logger.debug("Setting PK for member " + mbr);
+      if (logger.isDebugEnabled()) {
+        logger.debug("Setting PK for member " + mbr);
+      }
       encrypt.setPublicKey(publickey, mbr);
     }
   }
@@ -1401,7 +1432,9 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
   @Override
   public void setClusterSecretKey(byte[] clusterSecretKey) {
     if (encrypt != null) {
-      logger.debug("Setting cluster key");
+      if (logger.isDebugEnabled()) {
+        logger.debug("Setting cluster key");
+      }
       encrypt.setClusterKey(clusterSecretKey);
     }
   }
